"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setAllIndexedDB = exports.getAllIndexedDB = exports.ExportedIndexedDBDatabase = void 0;
const zod_1 = require("zod");
const database_names_1 = require("./database-names");
const get_1 = require("./get");
const set_1 = require("./set");
exports.ExportedIndexedDBDatabase = zod_1.z.object({
    name: zod_1.z.string(),
    data: zod_1.z.any(),
    securityOrigin: zod_1.z.string(),
});
/**
 * @param securityOrigin get this from the "application > IndexedDB" developper panel
 * @returns databases
 */
async function getAllIndexedDB(page, securityOrigin) {
    const dbNames = await database_names_1.getDatabaseNames(page, securityOrigin);
    const databases = [];
    for (const db of dbNames) {
        databases.push({
            name: db,
            data: await get_1.getIndexedDB(page, db),
            securityOrigin,
        });
    }
    return databases;
}
exports.getAllIndexedDB = getAllIndexedDB;
async function setAllIndexedDB(page, databases) {
    for (const db of databases) {
        if (!page.url().includes(db.securityOrigin)) {
            await page.goto(db.securityOrigin);
        }
        await set_1.setIndexedDB(page, db.data, db.name);
    }
}
exports.setAllIndexedDB = setAllIndexedDB;
//# sourceMappingURL=index.js.map