"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setSessionData = exports.getSessionData = void 0;
const cookies_1 = require("./providers/cookies");
const IndexedDB_1 = require("./providers/IndexedDB");
const localStorage_1 = require("./providers/localStorage");
const sessionStorage_1 = require("./providers/sessionStorage");
/**
 * @param securityOrigin to get this: Dev Tools > Application > IndexedDB > properties of a database > security origin
 * @returns
 */
async function getSessionData(page, securityOrigin) {
    return {
        localStorage: await localStorage_1.getLocalStorage(page),
        cookies: await cookies_1.getCookies(page),
        sessionStorage: await sessionStorage_1.getSessionStorage(page),
        indexedDBDatabases: await IndexedDB_1.getAllIndexedDB(page, securityOrigin),
    };
}
exports.getSessionData = getSessionData;
async function setSessionData(page, sessionData) {
    await Promise.all([
        cookies_1.setCookies(page, sessionData.cookies),
        localStorage_1.setLocalStorage(page, sessionData.localStorage),
        sessionStorage_1.setSessionStorage(page, sessionData.sessionStorage),
        IndexedDB_1.setAllIndexedDB(page, sessionData.indexedDBDatabases),
    ]);
}
exports.setSessionData = setSessionData;
//# sourceMappingURL=session.js.map